@@ -1,50 +1,20 @@
 extern crate lazy_static;
 
 use std::{fs, panic, thread};
-use std::sync::{Once, Arc, Mutex};
+use std::sync::{*};
+use std::sync::atomic::AtomicPtr;
+use std::sync::atomic::Ordering::Acquire;
+use std::thread::JoinHandle;
+use std::time::SystemTime;
 
-
-use lazy_static::lazy_static;
 use testcontainers::{*};
 use testcontainers::clients::Cli;
 use testcontainers::images::generic::{GenericImage, Stream, WaitFor};
-use std::ptr::{self, null_mut};
 
 use voltdb_client_rust::*;
-use std::thread::JoinHandle;
-use std::rc::Rc;
-use std::sync::atomic::{AtomicPtr, Ordering};
-use std::ops::{DerefMut, Deref};
-use std::sync::atomic::Ordering::Acquire;
-use std::time::{SystemTime, UNIX_EPOCH};
 
-
-lazy_static! {
-    static ref CLI: Cli = {
-        clients::Cli::default()
-    };
-     static ref DOCKER: Container<'static, Cli, GenericImage> = {
-            let wait = WaitFor::LogMessage { message: "Server completed initialization.".to_owned(), stream: Stream::StdOut };
-            let voltdb = GenericImage::new("voltdb/voltdb-community:9.2.1")
-                .with_env_var("HOST_COUNT", "1")
-                .with_wait_for(wait);
-            CLI.run(voltdb)
-    };
-}
-
-static mut VAL: String = String::new();
-static INIT: Once = Once::new();
 static POPULATE: Once = Once::new();
 
-fn init() -> String {
-    unsafe {
-        INIT.call_once(|| {
-            let host_port = DOCKER.get_host_port(21211);
-            VAL = String::from(format!("localhost:{}", host_port.unwrap()).to_owned());
-        });
-        return VAL.clone();
-    }
-}
 
 fn populate(node: &mut Node) {
     POPULATE.call_once(|| {
@@ -73,13 +43,6 @@ fn populate(node: &mut Node) {
     });
 }
 
-#[test]
-fn jar_upload() -> Result<(), VoltError> {
-    let url = init();
-    let mut node = get_node(url.as_str()).unwrap();
-    populate(&mut node);
-    Ok(())
-}
 
 fn execute_success(node: &mut Node, sql: &str) {
     let x = node.query(sql).unwrap();
@@ -92,7 +55,17 @@ fn execute_success(node: &mut Node, sql: &str) {
 
 
 #[test]
-fn table_column_test() -> Result<(), VoltError> {
+fn test_multiples_thread() -> Result<(), VoltError> {
+    let c = Cli::default();
+    let wait = WaitFor::LogMessage { message: "Server completed initialization.".to_owned(), stream: Stream::StdOut };
+    let voltdb = GenericImage::new("voltdb/voltdb-community:9.2.1")
+        .with_env_var("HOST_COUNT", "1")
+        .with_wait_for(wait);
+    let docker = c.run(voltdb);
+    let host_port = docker.get_host_port(21211);
+
+
+
     #[derive(Debug)]
     struct Test {
         t1: Option<bool>,
@@ -129,8 +102,9 @@ fn table_column_test() -> Result<(), VoltError> {
             }
         }
     }
-    let url = init();
-    let mut node = get_node(url.as_str()).unwrap();
+    let url = "localhost";
+    let port = host_port.unwrap();
+    let mut node = get_node(&*format!("{}:{}", url, port)).unwrap();
     populate(&mut node);
     let insert = "insert into test_types (T1) values (NULL);";
     execute_success(&mut node, insert);
@@ -155,14 +129,14 @@ fn table_column_test() -> Result<(), VoltError> {
     let rc = Arc::new(AtomicPtr::new(&mut node));
     let mut vec: Vec<JoinHandle<_>> = vec![];
     let start = SystemTime::now();
-    for i in 0..512 {
-        let mut local = Arc::clone(&rc);
+    for _ in 0..512 {
+        let local = Arc::clone(&rc);
         let handle = thread::spawn(move || unsafe {
             let load = local.load(Acquire);
             let res = &(*load).query("select * from test_types where t1 = 1;").unwrap();
             let mut table = block_for_result(&res).unwrap();
             table.advance_row();
-            let test: Test = table.map_row();
+            let _: Test = table.map_row();
         }
         );
         vec.push(handle);
